<?php

declare(strict_types=1);

namespace Drupal\Tests\openid_connect\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Test the disconnect user permission.
 *
 * @group openid_connect
 */
class UserPermissionTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'openid_connect',
    'externalauth',
  ];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * Confirm a user cannot access another user's connected accounts page.
   */
  public function testDisconnectPermissionDenied(): void {
    $account = $this->createUser([]);
    $target = $this->createUser([]);

    // Login and confirm the account can access the target user's connected accounts page.
    $this->drupalLogin($account);
    $this->drupalGet("/user/{$target->id()}/connected-accounts");
    $this->assertSession()
      ->statusCodeEquals(403);
  }


  /**
   * Test the `disconnect openid connected accounts` permission.
   */
  public function testDisconnectPermission(): void {
    $account = $this->createUser(['disconnect openid connected accounts']);
    $target = $this->createUser([]);

    // Login and confirm the account can access the target user's connected accounts page.
    $this->drupalLogin($account);
    $this->drupalGet("/user/{$target->id()}/connected-accounts");
    $this->assertSession()
      ->statusCodeEquals(200);
  }

}
